# <img src="https://raw.githubusercontent.com/cchandre/Polarimetry/master/pypolar/main_icon.png" alt="PyPOLAR Icon" valign="middle" width="50"/> [PyPOLAR](https://www.fresnel.fr/polarimetry)

![Version](https://img.shields.io/badge/version-v2.8.0-blue)
![Platform](https://img.shields.io/badge/platform-macOS%20%7C%20Windows%20%7C%20Linux-orange)
[![License](https://img.shields.io/badge/license-BSD-lightgray)](https://github.com/cchandre/Polarimetry/blob/master/LICENSE)
[![SWH](https://archive.softwareheritage.org/badge/swh:1:dir:fc8dc8178cb109c4990a92415a6c120fe00a55fb/)](https://archive.softwareheritage.org/swh:1:dir:fc8dc8178cb109c4990a92415a6c120fe00a55fb;origin=https://pypi.org/project/Polarimetry/;visit=swh:1:snp:b3e860dea4f01231ffe5921daa53aa245c2cb84a;anchor=swh:1:rel:7154b6e6d40eee2fd834a31fe5d7422916f9d83b;path=/polarimetry-2.8.0.0/)

PyPOLAR is a Python-based application designed to analyze polarization-resolved microscopy data, enabling the measurement of molecular orientation and order in biological samples.

---

### 🚀 Getting Started

**Desktop Installers:** Check out the [Latest Release](https://github.com/cchandre/Polarimetry/releases) to download the standalone version for your OS:
* **Windows:** `PyPOLAR_installer.exe`
* **macOS:** `PyPOLAR.dmg`

**Via PyPI:** PyPOLAR can be installed on any OS (Windows, macOS, Linux) via pip. See the [PyPI Installation Guide](https://github.com/cchandre/Polarimetry/wiki/Install-and-run-PyPOLAR-with-PyPI) for details.

---

### 🛠 Resources

* **Documentation:** [PyPOLAR Documentation](https://github.com/cchandre/Polarimetry/blob/master/pypolar/PyPOLAR_documentation.pdf)
* **Wiki:** [PyPOLAR Wiki](https://github.com/cchandre/Polarimetry/wiki)
* **Source Code:** [`PyPOLAR.py`](https://github.com/cchandre/Polarimetry/blob/master/pypolar/PyPOLAR.py)
* **Official Website:** [fresnel.fr/polarimetry](https://www.fresnel.fr/polarimetry)
* **Post-processing:** [Data Post-processing Guide](https://github.com/cchandre/Polarimetry/blob/master/AdditionalFiles/README.md)
* **Research:** [Publications using PyPOLAR](https://github.com/cchandre/Polarimetry/wiki/Publications)

<p align="center">
  <img src="https://raw.githubusercontent.com/cchandre/Polarimetry/master/pypolar/PyPOLAR_layout.png" alt="PyPOLAR Layout Interface" width="500"/>
</p>

---
**Contact:** [cristel.chandre@cnrs.fr](mailto:cristel.chandre@cnrs.fr)

